VideoMode

Enum VideoMode 

#[repr(u32)]
pub enum VideoMode {
Show 14 variants Text40x25_8x8 = 0, Text40x25_9x16 = 1, Text80x25_8x8 = 2, Text80x25_8x16 = 3, Text80x25_9x16 = 4, Text80x43_8x8 = 5, Text80x50_8x8 = 6, Graphics320x200 = 7, Graphics320x240 = 8, Graphics320x400 = 9, Graphics640x200 = 10, Graphics640x350 = 11, Graphics640x400 = 12, Graphics640x480 = 13,
}
A video mode.

This type maps to the videomode_t struct in the original framework. Each variant is either in text mode or graphics mode.

Variants



Text40x25_8x8 = 0

Text mode, 40 columns and 25 rows, 8x8 font size.



Text40x25_9x16 = 1

Text mode, 40 columns and 25 rows, 9x16 font size.



Text80x25_8x8 = 2

Text mode, 80 columns and 25 rows, 8x8 font size.



Text80x25_8x16 = 3

Text mode, 80 columns and 25 rows, 8x16 font size.

This is the mode set by default.



Text80x25_9x16 = 4

Text mode, 80 columns and 25 rows, 9x16 font size.



Text80x43_8x8 = 5

Text mode, 80 columns and 43 rows, 8x8 font size.



Text80x50_8x8 = 6

Text mode, 80 columns and 50 rows, 8x8 font size.



Graphics320x200 = 7

Graphics mode, 320x200 pixels.



Graphics320x240 = 8

Graphics mode, 320x240 pixels.



Graphics320x400 = 9

Graphics mode, 320x400 pixels.



Graphics640x200 = 10

Graphics mode, 640x200 pixels.



Graphics640x350 = 11

Graphics mode, 640x350 pixels.



Graphics640x400 = 12

Graphics mode, 640x400 pixels.



Graphics640x480 = 13

Graphics mode, 640x480 pixels.

Implementations

Source

impl VideoMode

pub fn kind(self) -> VideoModeKind

Gets the kind of video mode this is (text or graphics).

pub fn is_graphics(self) -> bool

Gets whether the given video mode is in graphics mode.

pub fn is_text(self) -> bool

Gets whether the given video mode is in text mode.

pub fn set_video_mode(self)

Sets the application video mode to this one.

Equivalent to the module’s set_video_mode.