pub enum VideoModeKind {
Text,
Graphics,
}Expand description
A simple descriptor for whether a video mode is in text or graphics mode.
Variants
Text
Text mode, where each cell is a character or glyph. and the resolution is defined via cell matrix and font size.
Graphics
Graphics mode, where the resolution is specified directly and the graphics are drawn to the screen in indexed color mode.